==> hubzero-cms-1.3.1_1.3.1.5.orig.tar.gz: hubzero-cms-1.3.1-1.3.1.5/cms/components/com_members/views/emails/tmpl/confirm.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Nicholas J. Kisseberth <nkissebe@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );
?>
This email is to confirm the email address for the <?php echo $this->sitename; ?> account: <?php echo $this->login; ?>.

Click the following link to confirm your email address and activate your <?php echo $this->sitename; ?> account.

<?php echo $this->baseURL . JRoute::_('index.php?option=' . $this->option . '&task=confirm&confirm=' . -$this->confirm); ?>

==> hubzero-cms-1.3.1_1.3.1.9.orig.tar.gz: hubzero-cms-1.3.1-1.3.1.9/cms/components/com_members/views/emails/tmpl/confirm.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Nicholas J. Kisseberth <nkissebe@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

$this->baseURL = rtrim(str_replace('/administrator', '', $this->baseURL), '/');

$link = JFactory::getConfig()->get('sef') && JFactory::getApplication()->isAdmin()
	? '/members/confirm?confirm=' . -$this->confirm
	: JRoute::_('index.php?option=' . $this->option . '&task=confirm&confirm=' . -$this->confirm);
?>
This email is to confirm the email address for the <?php echo $this->sitename; ?> account: <?php echo $this->login; ?>.

Click the following link to confirm your email address and activate your <?php echo $this->sitename; ?> account.

<?php echo $this->baseURL . $link; ?>
